@@ -74,8 +74,8 @@ nanotestz(n$send(data.frame(), block = FALSE))
 nanotest(is.data.frame(n1$recv(block = 500)))
 nanotestz(n1$send(c("test", "", "spec"), mode = "raw", block = 500))
 nanotest(identical(n$recv("character", block = 500), c("test", "", "spec")))
-nanotestz(n$send(c(1L, 0L, 0L), mode = "r"))
-nanotest(length(n1$recv("int", block = 500)) == 3L)
+nanotestz(n$send(1:5, mode = "r"))
+nanotest(length(n1$recv("int", block = 500)) == 5L)
 nanotestaio(saio <- n1$send_aio(Reduce(strcat, replicate(5, random(1e3L))), mode = 3L, timeout = 900))
 nanotestp(saio)
 nanotestaio(call_aio(saio))
@@ -103,7 +103,7 @@ nanotesterr(msg$data, "active")
 nanotest(identical(call_aio(n), n))
 nanotestaio(sraio <- n$send_aio(as.raw(0L), mode = "r", timeout = 500))
 nanotestaio(rraio <- n1$recv_aio(mode = 1L, timeout = 500))
-nanotestw(is_nul_byte(call_aio_(rraio)$data))
+nanotest(is_nul_byte(call_aio_(rraio)$data))
 nanotestaio(sraio <- n$send_aio(as.raw(1L), mode = "ra", timeout = 500))
 nanotestaio(rraio <- n1$recv_aio(mode = "raw", timeout = 500))
 nanotest(is.raw(call_aio(rraio)$data))
@@ -121,19 +121,19 @@ nanotestaio(rraio <- n1$recv_aio(mode = "i", timeout = 500))
 nanotest(is.integer(call_aio(rraio)$data))
 nanotestaio(sraio <- n$send_aio(as.raw(0L), mode = "raw", timeout = 500))
 nanotestaio(rraio <- n1$recv_aio(mode = "double", timeout = 500))
-nanotestw(is.raw(call_aio(rraio)$data))
+nanotest(is.raw(call_aio(rraio)$data))
 nanotestaio(sraio <- n$send_aio(as.raw(0L), mode = "raw", timeout = 500))
 nanotestaio(rraio <- n1$recv_aio(mode = "int", timeout = 500))
-nanotestw(is.raw(call_aio(rraio)$data))
+nanotest(is.raw(call_aio(rraio)$data))
 nanotestaio(sraio <- n$send_aio(as.raw(0L), mode = "raw", timeout = 500))
 nanotestaio(rraio <- n1$recv_aio(mode = "logical", timeout = 500))
 nanotestw(is.raw(call_aio(rraio)$data))
 nanotestaio(sraio <- n$send_aio(as.raw(0L), mode = "raw", timeout = 500))
 nanotestaio(rraio <- n1$recv_aio(mode = "numeric", timeout = 500))
-nanotestw(is.raw(call_aio(rraio)$data))
+nanotest(is.raw(call_aio(rraio)$data))
 nanotestaio(sraio <- n$send_aio(as.raw(0L), mode = "raw", timeout = 500))
 nanotestaio(rraio <- n1$recv_aio(mode = "complex", timeout = 500))
-nanotestw(is.raw(call_aio(rraio)$data))
+nanotest(is.raw(call_aio(rraio)$data))
 nanotesterr(opt(rraio[["aio"]], "false") <- 0L, "valid")
 nanotesterr(subscribe(rraio[["aio"]], "false"), "valid")
 nanotesterr(opt(rraio[["aio"]], "false"), "valid")
@@ -208,13 +208,16 @@ nanotesterr(err$result, "active")
 nanotestaio(err <- send_aio(ctx, "test"))
 nanotest(is_error_value(call_aio(err)$result))
 nanotest(is_error_value(call_aio_(err)$result))
-nanotest(is.integer(req$send(as.raw(1L), mode = 2L, block = 500)))
-nanotestaio(msg <- call_aio(recv_aio(ctx, mode = 8L, timeout = 500)))
-nanotestaio(saio <- send_aio(ctx, msg[["value"]], mode = 2L, timeout = 500))
+nanotest(is.integer(req$send(serialize(NULL, NULL, ascii = TRUE), mode = 2L, block = 500)))
+nanotestn(call_aio(recv_aio(ctx, mode = 1L, timeout = 500))[["value"]])
+nanotestaio(saio <- send_aio(ctx, as.raw(1L), mode = 2L, timeout = 500))
 nanotest(identical(req$recv(mode = 8L, block = 500), as.raw(1L)))
 nanotestaio(rek <- request(req$context, c(1+3i, 4+2i), send_mode = 2L, recv_mode = "complex", timeout = 500))
 nanotest(is.integer(reply(ctx, execute = identity, recv_mode = 3L, send_mode = "ra", timeout = 500)))
 nanotest(is.complex(call_aio(rek)[["data"]]))
+nanotestaio(rek <- request(req$context, c(1+3i, 4+2i), send_mode = "next", recv_mode = "serial", timeout = 500))
+nanotest(is.integer(reply(ctx, execute = identity, recv_mode = 1L, send_mode = 3L, timeout = 500)))
+nanotest(is.complex(call_aio(rek)[["data"]]))
 
 nanotest(is.pairlist(nxt <- next_config(refhook = list(function(x) serialize(x, NULL), unserialize))))
 nanotest(length(nxt) == 2L)
@@ -348,34 +351,30 @@ nanotesterr(socket(listen = "test"), "argument")
 
 nanotestnn(ncurl("http://www.cam.ac.uk/"))
 nanotestnn(ncurl("http://www.cam.ac.uk/", follow = FALSE, response = "date"))
-nanotestnn(ncurl("http://www.cam.ac.uk/", follow = FALSE, response = list("date")))
 nanotestnn(ncurl("http://www.cam.ac.uk/", follow = TRUE))
-nanotestnn(ncurl("http://postman-echo.com/post", convert = FALSE, method = "POST", headers = c(`Content-Type` = "text/plain"), data = "test", response = "server", timeout = 3000L))
-nanotestnn(ncurl("http://postman-echo.com/post", convert = FALSE, method = "POST", headers = list(`Content-Type` = "text/plain"), response = list("Date", "Server"), timeout = 3000))
+nanotestnn(ncurl("http://postman-echo.com/post", convert = FALSE, method = "POST", headers = c(`Content-Type` = "text/plain"), data = "test", response = c("Date", "Server"), timeout = 3000))
 nanotest(is_error_value(ncurl("http")$data))
+haio <- ncurl_aio("http://trin.cam.ac.uk/")
+nanotest(length(call_aio(haio)$headers))
 haio <- ncurl_aio("https://trin.cam.ac.uk/", convert = FALSE, response = "server")
 nanotest(is.integer(call_aio(haio)$status))
-haio <- ncurl_aio("https://trin.cam.ac.uk/", convert = FALSE, response = list("server"))
-nanotest(is.integer(call_aio(haio)$status))
-put1 <- ncurl_aio("http://postman-echo.com/put", method = "PUT", headers = c(Authorization = "Bearer token"), data = "test", response = c("date", "server"), timeout = 3000L)
+put1 <- ncurl_aio("http://postman-echo.com/put", method = "PUT", headers = c(Authorization = "Bearer token"), data = "test", response = c("Date", "server"), timeout = 3000L)
+nanotestp(put1)
 nanotest(is.integer(call_aio_(put1)$status))
 nanotestnn(put1$headers)
 nanotestnn(put1$data)
-put2 <- ncurl_aio("http://postman-echo.com/put", method = "PUT", headers = list(Authorization = "Bearer token"), response = list("date", "server"), timeout = 3000L)
-nanotestp(put2)
-nanotest(is.integer(call_aio(put2)$status))
-nanotest(is.null(stop_aio(put2)))
+nanotest(is.null(stop_aio(put1)))
 haio <- ncurl_aio("https://i.i")
 nanotest(is_error_value(call_aio(haio)$data))
 nanotestp(haio$data)
 ncaio <- ncurl_aio("https://shikokuchuo.net/nanonext/reference/figures/logo.png")
-nanotestw(is.raw(call_aio(ncaio)$data) || is_error_value(ncaio$data))
+nanotest(is.raw(call_aio(ncaio)$data) || is_error_value(ncaio$data))
 nanotest(is_error_value(ncurl_aio("http")$data))
-sess <- ncurl_session("https://postman-echo.com/post", method = "POST", headers = c(`Content-Type` = "text/plain"), data = "test", response = "server", timeout = 3000L)
+sess <- ncurl_session("https://postman-echo.com/post", method = "POST", headers = c(`Content-Type` = "text/plain"), data = "test", response = c("date", "Server"), timeout = 3000L)
 nanotestnn(sess)
 nanotest(is_error_value(sess) || length(transact(sess)) == 3L)
 nanotest(is_error_value(sess) || close(sess) == 0L)
-sess <- ncurl_session("https://postman-echo.com/post", convert = FALSE, method = "POST", headers = list(`Content-Type` = "text/plain"), response = list("Date", "Server"), timeout = 3000)
+sess <- ncurl_session("https://postman-echo.com/post", convert = FALSE, method = "POST", headers = c(`Content-Type` = "text/plain"), timeout = 3000)
 nanotestnn(sess)
 nanotest(is_error_value(sess) || length(transact(sess)) == 3L)
 nanotest(is_error_value(sess) || close(sess) == 0L)
@@ -421,20 +420,20 @@ if (length(s)) {
   nanotestnn(recv(s, block = 500L))
   nanotest(is.character(opt(s, "ws:response-headers")))
   nanotesterr(opt(s, "ws:request-headers") <- "test\n", 24)
-  nanotest(is.integer(send(s, "message1", block = 500L)))
+  nanotest(is.integer(send(s, c("message1", "test"), block = 500L)))
   nanotestnn(recv(s, block = FALSE))
   nanotest(is.integer(send(s, "message2", block = FALSE)))
   nanotestnn(recv(s, mode = 9L, block = 100))
   nanotest(is.integer(send(s, 2L, block = 500)))
   nanotestaio(sr <- recv_aio(s, mode = "i", timeout = 500L, n = 8192L))
-  nanotestw(length(call_aio(sr)[["data"]]))
+  nanotest(length(call_aio(sr)[["data"]]))
   nanotestn(stop_aio(sr))
   nanotestaio(ss <- send_aio(s, "async", timeout = 500L))
   nanotest(is.integer(call_aio(ss)[["result"]]))
   nanotestn(stop_aio(ss))
   nanotest(is.integer(send(s, 12.56, mode = "raw", block = 500L)))
   nanotestaio(sr <- recv_aio_signal(s, mode = "double", timeout = 500L, cv = cv))
-  nanotestw(length(call_aio_(sr)[["data"]]))
+  nanotest(length(call_aio_(sr)[["data"]]))
   nanotest(cv_value(cv) > 0L)
   nanotest(wait(cv))
   nanotest(is.character(opt(s, "ws:request-headers")))
@@ -519,13 +518,10 @@ nanotest(sha256("test") == "9f86d081884c7d659a2feaa0c55ad015a3bf4f1b2b0b822cd15d
 nanotest(length(sha256(c("one", "two"), key = "PRIVATE_key", convert = FALSE)) == 32L)
 nanotest(nchar(sha512(c(1.1, 2.2), as.raw(1L))) == 128L)
 nanotest(length(sha512("testing", convert = FALSE)) == 64L)
-nanotest(length(sha384(as.list(random(1e3L)), "KEY", convert = FALSE)) == 48L)
+nanotest(length(sha384(runif(5e3L), "KEY", convert = FALSE)) == 48L)
 nanotest(nchar(sha384(7000L, key = NULL, convert = TRUE)) == 96L)
 nanotest(length(sha224(c("one", "two"), key = "PRIVATE_key", convert = FALSE)) == 28L)
 nanotest(sha224(as.raw(0L)) == "fff9292b4201617bdc4d3053fce02734166a683d7d858a7f5f59b073")
-nanotest(length(sha1("testingnoncrypto", convert = FALSE)) == 20L)
-nanotest(nchar(sha1(c(1, 2), key = "secret")) == 40L)
-nanotest(is.raw(sha1(quote(a + 2), convert = FALSE)))
 nanotest(is.character(sha256(quote(a))))
 nanotest(base64enc("test") == "dGVzdA==")
 nanotest(base64dec(base64enc("test")) == "test")
